@@ -31,6 +31,8 @@
 #include "ApplicationBackend.h"
 #include "Transaction.h"
 
+class QDeclarativeView;
+class QGraphicsBlurEffect;
 class QLabel;
 class QProgressBar;
 class QPropertyAnimation;
@@ -46,7 +48,6 @@ class Application;
 class ClickableLabel;
 class Review;
 class ReviewsWidget;
-class ScreenShotViewer;
 
 // Widget for showing details about a single application
 class ApplicationDetailsWidget : public QScrollArea
@@ -75,7 +76,7 @@ private:
     QProgressBar *m_progressBar;
     QPushButton *m_cancelButton;
     QLabel *m_longDescLabel;
-    ClickableLabel *m_screenshotLabel;
+    QDeclarativeView *m_screenshotView;
     QLabel *m_websiteLabel;
     AddonsWidget *m_addonsWidget;
     QLabel *m_size;
@@ -84,11 +85,11 @@ private:
     QLabel *m_support;
     ReviewsWidget *m_reviewsWidget;
 
-    QPropertyAnimation *m_fadeScreenshot;
     KPixmapSequenceOverlayPainter *m_throbberWidget;
+    QGraphicsBlurEffect *m_blurEffect;
+    QPropertyAnimation *m_fadeBlur;
 
     KTemporaryFile *m_screenshotFile;
-    ScreenShotViewer *m_screenshotDialog;
 
 private Q_SLOTS:
     void workerEvent(QApt::WorkerEvent event, Transaction *transaction);
@@ -96,12 +97,10 @@ private Q_SLOTS:
     void showTransactionState(Transaction *transaction);
     void transactionCancelled(Application *app);
     void populateZeitgeistInfo();
-    void fadeInScreenshot();
     void fetchScreenshot(QApt::ScreenshotType screenshotType);
-    void thumbnailFetched(KJob *job);
     void screenshotFetched(KJob *job);
+    void overlayClosed();
     void screenshotLabelClicked();
-    void onScreenshotDialogClosed();
     void actionButtonClicked();
     void cancelButtonClicked();
     void populateAddons();
